==> dde-network-core_2.0.36.tar.xz: BUILD/src/translations/dde-network-core_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>QObject</name>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key</source>
        <translation>Clave WEP de 40/128-bit</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS tunelizado</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP protegido</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetailInterRealize</name>
    <message>
        <source>Hotspot</source>
        <translation>Punto de acceso</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocolo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo de seguridad</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de red</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primario</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefijo</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidad</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetailNMRealize</name>
    <message>
        <source>automatic</source>
        <translation>Automático </translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Punto de acceso</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocolo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo de seguridad</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de red</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primario</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefijo</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidad</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo deshabilitado</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Sin conexión</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cable de red desconectado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentificando</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obteniendo dirección IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Conectado</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicto de IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Fallido</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Obtención de la dirección</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Red cableada</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Red cableada %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Red inalámbrica</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Red inalámbrica %1</translation>
    </message>
</context>
</TS>

==> dde-network-core_2.0.58.tar.xz: BUILD/src/translations/dde-network-core_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>QObject</name>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>WEP 40/128-bit Key</source>
        <translation>Clave WEP de 40/128-bit</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS tunelizado</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP protegido</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetailInterRealize</name>
    <message>
        <source>Hotspot</source>
        <translation>Compartir conexión</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocolo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo de seguridad</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de red</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primario</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefijo</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidad</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetailNMRealize</name>
    <message>
        <source>automatic</source>
        <translation>Automático </translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Compartir conexión</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocolo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo de seguridad</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de red</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primario</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefijo</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidad</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo deshabilitado</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Sin conexión</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cable de red desconectado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentificando</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obteniendo dirección IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Conectado</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicto de IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Falló</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Obtención de la dirección</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Red cableada</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Red cableada %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Red inalámbrica</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Red inalámbrica %1</translation>
    </message>
</context>
</TS>
